#!/bin/bash
#
# client load generator, send any questions to ddiss@suse.de
#
# Copyright (C) David Disseldorp 2014
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

SCRIPT_NAME=`basename $0`
GEN_LOAD_CMD="./gen_load_cmds.sh"
#CONN_SLEEP=0.01
CONN_SLEEP=0.10
CONN_COUNT=1000
SRC_FILE_SIZE_K=100
SRC_FILE="./test-file"
#TGT_HOSTS="192.168.1.8 192.168.1.9 192.168.1.10"
TGT_HOSTS="smbserver.example.com"
SHARE_NAME='SMBSHARE'
USER='administrator'
PASS='PASSWORD'
LOG_FILE_SFX=$$-${SCRIPT_NAME}.log

function _kill_load
{
	echo "caught signal, killing load"
	killall `basename $GEN_LOAD_CMD`
	echo "load killed"
}

trap "_kill_load; exit 1" SIGINT SIGTERM
trap "echo child process ended" SIGCHLD

rm $SRC_FILE
dd if=/dev/zero of=${SRC_FILE} bs=1K count=${SRC_FILE_SIZE_K}

for srv in $TGT_HOSTS; do
	for i in `seq 1 $CONN_COUNT`; do
#		log_file="${srv}-client${i}_${LOG_FILE_SFX}"
		log_file="/dev/null"
		echo "starting client $i, logging to $log_file"
		($GEN_LOAD_CMD $SRC_FILE test-${srv}-${i} \
			| smbclient -U "${USER}"%"${PASS}" //${srv}/${SHARE_NAME} \
			&> $log_file || echo "client $i exited") &
		# stagger connections, to avoid all hitting the server at the same time
		sleep $CONN_SLEEP
	done
done

echo "All clients started, hit ctrl-C to stop load"

wait
